.. _recipe_asr.stiffness:

asr.stiffness
=============


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.stiffness`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.stiffness.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.stiffness

or as a python module

.. code-block:: console

   $ python -m asr.stiffness

Detailed description
--------------------
Stiffness tensor.

Steps
-----


asr.stiffness
^^^^^^^^^^^^^
.. autofunction:: asr.stiffness.main
   